@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: GeometryTestFactory.cpp,v 1.12 2004/12/08 13:54:43 strk Exp $
+ * $Id: GeometryTestFactory.cpp,v 1.12.2.1 2005/05/23 17:10:08 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,7 +13,7 @@
  *
  **********************************************************************/
 
-#include <math.h>
+#include <cmath>
 
 #include <geos/geom.h>
 #include "bigtest.h"
@@ -126,6 +126,9 @@ Polygon* GeometryTestFactory::createSineStar(GeometryFactory *fact,double basex,
 
 /**********************************************************************
  * $Log: GeometryTestFactory.cpp,v $
+ * Revision 1.12.2.1  2005/05/23 17:10:08  strk
+ * Stricter C++ syntax (math.h=>cmath, ieeefp.h in "C" block)
+ *
  * Revision 1.12  2004/12/08 13:54:43  strk
  * gcc warnings checked and fixed, general cleanups.
  *
