@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: DefaultCoordinateSequence.cpp,v 1.3 2004/12/03 22:52:56 strk Exp $
+ * $Id: DefaultCoordinateSequence.cpp,v 1.3.2.1 2005/05/23 18:41:51 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,6 +13,9 @@
  *
  **********************************************************************
  * $Log: DefaultCoordinateSequence.cpp,v $
+ * Revision 1.3.2.1  2005/05/23 18:41:51  strk
+ * Replaced sprintf uses with ostringstream
+ *
  * Revision 1.3  2004/12/03 22:52:56  strk
  * enforced const return of CoordinateSequence::toVector() method to derivate classes.
  *
@@ -26,7 +29,6 @@
 
 
 #include <geos/geom.h>
-#include <stdio.h>
 
 namespace geos {
 
@@ -112,11 +114,12 @@ void DefaultCoordinateSequence::deleteAt(int pos){
 string DefaultCoordinateSequence::toString() const {
 	string result("");
 	if (getSize()>0) {
-		char buffer[100];
+		//char buffer[100];
 		for (unsigned int i=0; i<vect->size(); i++) {
 			Coordinate& c=(*vect)[i];
-			sprintf(buffer,"(%g,%g,%g) ",c.x,c.y,c.z);
-			result.append(buffer);
+			//sprintf(buffer,"(%g,%g,%g) ",c.x,c.y,c.z);
+			//result.append(buffer);
+			result.append(c.toString());
 		}
 		result.append("");
 	}
