@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: Envelope.cpp,v 1.17 2004/11/08 10:58:08 strk Exp $
+ * $Id: Envelope.cpp,v 1.17.2.1 2005/05/23 18:41:51 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,8 +13,8 @@
  *
  **********************************************************************/
 
+#include <sstream>
 #include <geos/geom.h>
-#include <stdio.h>
 
 namespace geos {
 
@@ -479,12 +479,9 @@ bool Envelope::overlaps(const Envelope *other) const {
  *@return    a <code>string</code> of the form <I>Env[minx:maxx,miny:maxy]</I>
  */
 string Envelope::toString() const {
-	string result("");
-	char buffer[255];
-	sprintf(buffer,"Env[%g:%g,%g:%g]",minx,maxx,miny,maxy);
-	result.append(buffer);
-	result.append("");
-	return result;
+	ostringstream s;
+	s<<"Env["<<minx<<":"<<maxx<<","<<miny<<":"<<maxy<<"]";
+	return s.str();
 }
 
 /**
@@ -535,6 +532,9 @@ int Envelope::hashCode() const{
 
 /**********************************************************************
  * $Log: Envelope.cpp,v $
+ * Revision 1.17.2.1  2005/05/23 18:41:51  strk
+ * Replaced sprintf uses with ostringstream
+ *
  * Revision 1.17  2004/11/08 10:58:08  strk
  * Optimized the ::intersect function to avoid nested function calls.
  *
