@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: LinearRing.cpp,v 1.24 2004/12/16 16:27:24 strk Exp $
+ * $Id: LinearRing.cpp,v 1.23 2004/12/03 22:52:56 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,9 +13,6 @@
  *
  **********************************************************************
  * $Log: LinearRing.cpp,v $
- * Revision 1.24  2004/12/16 16:27:24  strk
- * Fixed LinearRing::clone() to return LinearRing instead of LineString
- *
  * Revision 1.23  2004/12/03 22:52:56  strk
  * enforced const return of CoordinateSequence::toVector() method to derivate classes.
  *
@@ -129,10 +126,6 @@ void LinearRing::setPoints(CoordinateSequence* cl){
 	//delete v;
 }
 
-Geometry* LinearRing::clone() const {
-	return new LinearRing(*this);
-}
-
 GeometryTypeId
 LinearRing::getGeometryTypeId() const {
 	return GEOS_LINEARRING;
