@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: opOverlay.h,v 1.8 2004/12/08 13:54:43 strk Exp $
+ * $Id: opOverlay.h,v 1.8.2.1 2005/06/28 01:07:11 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -356,23 +356,36 @@ public:
  */
 class PointBuilder {
 private:
+
 	OverlayOp *op;
 	const GeometryFactory *geometryFactory;
-	PointLocator *ptLocator;
-	vector<Node*>* collectNodes(int opCode);
-	/**
-	* This method simplifies the resultant Geometry by finding and eliminating
-	* "covered" points.
-	* A point is covered if it is contained in another element Geometry
-	* with higher dimension (e.g. a point might be contained in a polygon,
-	* in which case the point can be eliminated from the resultant).
-	*/
-	vector<Point*>* simplifyPoints(vector<Node*>* resultNodeList);
+	void extractNonCoveredResultNodes(int opCode);
+
+	/*
+	 * Converts non-covered nodes to Point objects and adds them to
+	 * the result.
+	 *
+	 * A node is covered if it is contained in another element Geometry
+	 * with higher dimension (e.g. a node point might be contained in
+	 * a polygon, in which case the point can be eliminated from
+	 * the result).
+	 *
+	 * @param n the node to test
+	 */
+	void filterCoveredNodeToPoint(const Node *);
+
+	vector<Point*> *resultPointList;
+
 public:
-	PointBuilder(OverlayOp *newOp, const GeometryFactory *newGeometryFactory, PointLocator *newPtLocator);
-	/**
-	* @return a list of the Points in the result of the specified overlay operation
-	*/
+
+	PointBuilder(OverlayOp *newOp,
+		const GeometryFactory *newGeometryFactory,
+		PointLocator *newPtLocator=NULL);
+
+	/*
+	 * @return a list of the Points in the result of the specified
+	 * overlay operation
+	 */
 	vector<Point*>* build(int opCode);
 };
 
@@ -573,6 +586,9 @@ public:
 
 /**********************************************************************
  * $Log: opOverlay.h,v $
+ * Revision 1.8.2.1  2005/06/28 01:07:11  strk
+ * improved extraction of result points in overlay op
+ *
  * Revision 1.8  2004/12/08 13:54:43  strk
  * gcc warnings checked and fixed, general cleanups.
  *
